@@ -1,6 +1,6 @@
 package Net::Kestrel;
 BEGIN {
-  $Net::Kestrel::VERSION = '0.02';
+  $Net::Kestrel::VERSION = '0.03';
 }
 use Moose;
 
@@ -29,6 +29,13 @@ has 'port' => (
     default => 2222
 );
 
+
+has 'timeout' => (
+    is => 'ro',
+    isa => 'Int',
+    default => 3
+);
+
 has _connection => (
     is => 'rw',
     isa => 'IO::Socket::INET',
@@ -37,12 +44,21 @@ has _connection => (
 
 sub _build__connection {
     my ($self) = @_;
-    
-    return IO::Socket::INET->new(
+
+    $SIG{PIPE} = sub { die 'Connection to '.$self->host.' port '.$self->port.' went away!' };
+
+    my $sock = IO::Socket::INET->new(
         PeerAddr => $self->host,
         PeerPort => $self->port,
-        Proto => 'tcp'
+        Proto => 'tcp',
+        Timeout => $self->timeout
     );
+
+    if(!defined($sock)) {
+        die('Failed to connect to '.$self->host.' port '.$self->port);
+    }
+
+    return $sock;
 }
 
 
@@ -54,6 +70,14 @@ sub confirm {
 }
 
 
+sub delete {
+    my ($self, $queue) = @_;
+
+    my $cmd = "delete $queue";
+    return $self->_write_and_read($cmd);
+}
+
+
 sub flush {
     my ($self, $queue) = @_;
 
@@ -131,7 +155,7 @@ Net::Kestrel - Kestrel Client for Perl
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -167,12 +191,21 @@ The ip address of the Kestrel host you want to connect to.
 
 The port to connect to.  Defaults to 22133.
 
+=head2 timeout
+
+The timeout value for operations.  Defaults to 3 seconds.
+
 =head1 METHODS
 
 =head2 confirm ($queuename, $count)
 
 Confirms $count items from the queue.
 
+=head2 delete ($queuename)
+
+Delete the specified queue.  B<NOTE: This is not yet supported in Kestrel's
+text protocol.>
+
 =head2 flush ($queuename)
 
 Flush (empty) the specified queue.
